@@ -6,7 +6,6 @@ use strict;
 use Pod::Man;
 
 use Config;
-use Config::AutoConf;
 use ExtUtils::ParseXS;
 use ExtUtils::Mkbootstrap;
 use Capture::Tiny 'capture';
@@ -14,7 +13,6 @@ use ExtUtils::LibBuilder;
 use File::Spec::Functions qw.catdir catfile.;
 use File::Path qw.mkpath.;
 use ExtUtils::PkgConfig;
-use Parse::Yapp;
 
 my $pedantic = $ENV{AMBS_PEDANTIC} || 0;
 
@@ -164,9 +162,9 @@ sub ACTION_code {
 
     $self->_set_libbuilder();
 
-    my_yapp(module => 'Lingua::NATools::PatternRules',
-            output => 'lib/Lingua/NATools/PatternRules.pm',
-            input => 'lib/Lingua/NATools/PatternRules.yp');
+
+    `yapp -m Lingua::NATools::PatternRules -o lib/Lingua/NATools/PatternRules.pm lib/Lingua/NATools/PatternRules.yp`;
+
 
     $self->dispatch("create_manpages");
     $self->dispatch("create_objects");
@@ -578,17 +576,5 @@ EOP
 
 sub FAIL { print "Error, can't continue\n"; exit 0; }
 
-sub my_yapp {
-    my %ops = @_;
-
-    my ($parser) = Parse::Yapp->new(inputfile => $ops{input});
-
-    open OUT, ">", $ops{output} or die "Can't create $ops{output} file";
-    print OUT $parser->Output(classname => $ops{module},
-                              standalone => 0,
-                              linenumbers => 1,
-                              template => "");
-    close OUT;
-}
 
 1;
